==> tecfy_core_package-0.1.30.tar.gz: lib/main.dart <==
part of tecfy_core_client_package;

class TecfyCoreApp extends StatelessWidget {
  static GlobalKey<NavigatorState> appGlobalkey = GlobalKey<NavigatorState>();
  // static GlobalKey<ScaffoldState> appGlobalPagekey = GlobalKey<ScaffoldState>();
  static set apiURL(v) => ConfigService.apiURL = v;
  static set wsURL(v) => ConfigService.wsURL = v;
  // static String wsURL = '';
  static Map<String, IEntityTransaction> entityServices =
      Map<String, IEntityTransaction>();
  static set themeConfig(IThemeConfig v) => TecfyBasicApp.themeConfig = v;
  static IThemeConfig get themeConfig => TecfyBasicApp.themeConfig;
  static Image logo;
  static Image backgoundImage;
  static ITranslateService translateService;
  static void Function(BuildContext) navigateToDefaultPage = (c) =>
      AppNavigator.navigateTo(c, () => DashboardPage(),
          replaceAll: true, animationType: AnimationTypes.opacity);
  static Future Function(Database, int, int) updateSqlLiteDb =
      (d, f, t) async {};
  static int appDbVersion = 0;
  static IMenuInterface menuService;
  static PackageInfo packageInfo;
  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    // kReleaseMode;
    if (kReleaseMode) {
      return StreamBuilder<Language>(
          stream: AppLocale.languageStream,
          initialData: LocalConfigService.language,
          builder: (context, languageSnapshot) {
            return getApp(languageSnapshot.data);
          });
    } else {
      return getApp(LocalConfigService.language);
    }
  }

  getApp(Language language) {
    return MaterialApp(
      key: UniqueKey(),
      //debugShowCheckedModeBanner: false,
      title: 'Application',
      navigatorKey: appGlobalkey,
      theme: ThemeService.getMainThemeAndroid(),
      home: SplashScreenPage(),
      supportedLocales: [const Locale('ar', 'SA'), const Locale('en', 'US')],
      localizationsDelegates: [
        const AppLocalizationsDelegate(),
        GlobalMaterialLocalizations.delegate,
        GlobalWidgetsLocalizations.delegate
      ],
      locale: language == Language.arabic
          ? const Locale('ar', 'SA')
          : const Locale('en', 'US'),
      localeResolutionCallback:
          (Locale deviceLocale, Iterable<Locale> supportedLocales) {
        print(
            '---------------------------------- Check Language ------------------------------------- $language');
        ConfigService.isRTL = (language == Language.arabic);
        var selectedLanguageCode = (language == Language.arabic) ? 'ar' : 'en';
        var lcl = supportedLocales
                .where((d) => d.languageCode == selectedLanguageCode)
                .first ??
            supportedLocales.first;
        print('-------------------------------------------------- ' +
            lcl.languageCode);
        return lcl;
      },
    );
  }

  static void init({String mapAPI}) {
    if (mapAPI != null) {
      GoogleMap.init(mapAPI);
    }
  }
}

// class TecfyMainApplication extends StatefulWidget {
//   static restartApp(BuildContext context) {
//     final _TecfyMainApplicationState state = context
//         .ancestorStateOfType(const TypeMatcher<_TecfyMainApplicationState>());
//     state.restartApp();
//   }

//   @override
//   _TecfyMainApplicationState createState() => new _TecfyMainApplicationState();
// }

// class _TecfyMainApplicationState extends State<TecfyMainApplication> {
//   Key key = new UniqueKey();
//   Widget child;

//   void restartApp() {
//     this.setState(() {
//       key = new UniqueKey();
//     });
//   }

//   @override
//   void initState() {
//     child = TecfyCoreApp();
//     super.initState();
//   }

//   @override
//   Widget build(BuildContext context) {
//     return new Container(
//       key: key,
//       child: child,
//     );
//   }
// }

==> tecfy_core_package-0.1.31.tar.gz: lib/main.dart <==
part of tecfy_core_client_package;

class TecfyCoreApp extends StatelessWidget {
  static GlobalKey<NavigatorState> appGlobalkey = GlobalKey<NavigatorState>();
  // static GlobalKey<ScaffoldState> appGlobalPagekey = GlobalKey<ScaffoldState>();
  static set apiURL(v) => ConfigService.apiURL = v;
  static set wsURL(v) => ConfigService.wsURL = v;
  // static String wsURL = '';
  static Map<String, IEntityTransaction> entityServices =
      Map<String, IEntityTransaction>();
  static set themeConfig(IThemeConfig v) => TecfyBasicApp.themeConfig = v;
  static IThemeConfig get themeConfig => TecfyBasicApp.themeConfig;
  static Image logo;
  static Image backgoundImage;
  static ITranslateService translateService;
  static void Function(BuildContext) navigateToDefaultPage = (c) =>
      AppNavigator.navigateTo(c, () => DashboardPage(),
          replaceAll: true, animationType: AnimationTypes.opacity);
  static Future Function(Database, int, int) updateSqlLiteDb =
      (d, f, t) async {};
  static int appDbVersion = 0;
  static IMenuInterface menuService;
  static PackageInfo packageInfo;
  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    // kReleaseMode;
    if (kReleaseMode) {
      return StreamBuilder<Language>(
          stream: AppLocale.languageStream,
          initialData: LocalConfigService.language,
          builder: (context, languageSnapshot) {
            return getApp(languageSnapshot.data);
          });
    } else {
      return getApp(LocalConfigService.language);
    }
  }

  getApp(Language language) {
    return MaterialApp(
      key: UniqueKey(),
      //debugShowCheckedModeBanner: false,
      title: 'Application',
      navigatorKey: appGlobalkey,
      theme: ThemeService.getMainThemeAndroid(),
      home: SplashScreenPage(),
      supportedLocales: [const Locale('ar', 'SA'), const Locale('en', 'US')],
      localizationsDelegates: [
        const AppLocalizationsDelegate(),
        GlobalMaterialLocalizations.delegate,
        GlobalWidgetsLocalizations.delegate,
        DefaultCupertinoLocalizations.delegate
      ],
      locale: language == Language.arabic
          ? const Locale('ar', 'SA')
          : const Locale('en', 'US'),
      localeResolutionCallback:
          (Locale deviceLocale, Iterable<Locale> supportedLocales) {
        print(
            '---------------------------------- Check Language ------------------------------------- $language');
        ConfigService.isRTL = (language == Language.arabic);
        var selectedLanguageCode = (language == Language.arabic) ? 'ar' : 'en';
        var lcl = supportedLocales
                .where((d) => d.languageCode == selectedLanguageCode)
                .first ??
            supportedLocales.first;
        print('-------------------------------------------------- ' +
            lcl.languageCode);
        return lcl;
      },
    );
  }

  static void init({String mapAPI}) {
    if (mapAPI != null) {
      GoogleMap.init(mapAPI);
    }
  }
}

// class TecfyMainApplication extends StatefulWidget {
//   static restartApp(BuildContext context) {
//     final _TecfyMainApplicationState state = context
//         .ancestorStateOfType(const TypeMatcher<_TecfyMainApplicationState>());
//     state.restartApp();
//   }

//   @override
//   _TecfyMainApplicationState createState() => new _TecfyMainApplicationState();
// }

// class _TecfyMainApplicationState extends State<TecfyMainApplication> {
//   Key key = new UniqueKey();
//   Widget child;

//   void restartApp() {
//     this.setState(() {
//       key = new UniqueKey();
//     });
//   }

//   @override
//   void initState() {
//     child = TecfyCoreApp();
//     super.initState();
//   }

//   @override
//   Widget build(BuildContext context) {
//     return new Container(
//       key: key,
//       child: child,
//     );
//   }
// }
